Documentation
¶
Overview ¶
Package gemfyi provides a Go client for the GemFYI API (gemfyi.com).
GemFYI — zero dependencies, no authentication required.
Usage:
client := gemfyi.NewClient()
result, err := client.Search("query")
Index ¶
- Constants
- type Client
- func (c *Client) Categories() (map[string]interface{}, error)
- func (c *Client) Category(slug string) (map[string]interface{}, error)
- func (c *Client) Comparison(slug string) (map[string]interface{}, error)
- func (c *Client) Comparisons() (map[string]interface{}, error)
- func (c *Client) Faq(slug string) (map[string]interface{}, error)
- func (c *Client) Faqs() (map[string]interface{}, error)
- func (c *Client) Gem(slug string) (map[string]interface{}, error)
- func (c *Client) Gems() (map[string]interface{}, error)
- func (c *Client) Glossary() (map[string]interface{}, error)
- func (c *Client) GlossaryCategories() (map[string]interface{}, error)
- func (c *Client) GlossaryCategory(slug string) (map[string]interface{}, error)
- func (c *Client) Guide(slug string) (map[string]interface{}, error)
- func (c *Client) GuideSeries() (map[string]interface{}, error)
- func (c *Client) GuideSery(slug string) (map[string]interface{}, error)
- func (c *Client) Guides() (map[string]interface{}, error)
- func (c *Client) Origin(slug string) (map[string]interface{}, error)
- func (c *Client) Origins() (map[string]interface{}, error)
- func (c *Client) Search(query string) (map[string]interface{}, error)
- func (c *Client) Term(slug string) (map[string]interface{}, error)
Constants ¶
const DefaultBaseURL = "https://gemfyi.com"
DefaultBaseURL is the default API base URL.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client is a GemFYI API client.
func (*Client) Categories ¶
Categories returns a list of categories.
func (*Client) Comparison ¶
Comparison returns details for a comparison by slug.
func (*Client) Comparisons ¶
Comparisons returns a list of comparisons.
func (*Client) GlossaryCategories ¶
GlossaryCategories returns a list of glossary categories.
func (*Client) GlossaryCategory ¶
GlossaryCategory returns details for a glossary category by slug.
func (*Client) GuideSeries ¶
GuideSeries returns a list of guide series.
Click to show internal directories.
Click to hide internal directories.